import type { IDS, PageQuery, PageResult } from '#/api/common';
import type { SpareInoutdtVO } from '#/api/eims/spare-inoutdt/model';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  root = '/eims/spareInoutdt',
  spareInoutdtExport = '/eims/spareInoutdt/export',
  spareInoutdtList = '/eims/spareInoutdt/list'
}

/**
 * 查询【备件出入库明细】列表
 * @param query
 * @returns {*}
 */

export function listSpareInoutdt(params?: PageQuery) {
  return requestClient.get<PageResult<SpareInoutdtVO>>(Api.spareInoutdtList, { params });
}

/**
 * 查询【备件出入库明细】详细
 * @param spareInoutdtId
 */
export function getSpareInoutdt(spareInoutdtId: any) {
  return requestClient.get<SpareInoutdtVO>(`${Api.root}/${spareInoutdtId}`);
}

/**
 * 新增【备件出入库明细】
 * @param data
 */
export function addSpareInoutdt(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改【备件出入库明细】
 * @param data
 */
export function updateSpareInoutdt(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除【备件出入库明细】
 * @param spareInoutdtIds
 */
export function delSpareInoutdt(spareInoutdtIds: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${spareInoutdtIds}`);
}

/**
 * 导出【备件出入库明细】
 * @param data
 */
export function spareInoutdtExport(data: any) {
  return commonExport(Api.spareInoutdtExport, data);
}
